@@ -27,7 +27,7 @@ use Exporter::Tidy
   ];
 
 our @ISA     = 'DBI';
-our $VERSION = '0.0.45_2';
+our $VERSION = '0.0.46';
 
 sub ejoin {
     my $joiner = shift;
@@ -886,7 +886,7 @@ DBIx::ThinSQL - A lightweight SQL helper for DBI
 
 =head1 VERSION
 
-0.0.45_2 (2016-07-29) development release.
+0.0.46 (2016-10-16) development release.
 
 =head1 SYNOPSIS
 
